Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2904)

Unified Diff: chrome/browser/background/background_application_list_model.cc

Issue 10887032: If any installed app has push messaging permission, then background launch Chrome (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: revert accidental change Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/background/background_application_list_model.cc
diff --git a/chrome/browser/background/background_application_list_model.cc b/chrome/browser/background/background_application_list_model.cc
index 08b6d1c6d7f94141ae6368aa7ba932e102e6f999..e0c6010b6ff1f608cc3f3bcf85080be4aef3d8d4 100644
--- a/chrome/browser/background/background_application_list_model.cc
+++ b/chrome/browser/background/background_application_list_model.cc
@@ -277,8 +277,10 @@ bool BackgroundApplicationListModel::IsBackgroundApp(
// 2) It is a hosted app, and has a background contents registered or in the
// manifest.
- // Not a background app if we don't have the background permission.
- if (!extension.HasAPIPermission(APIPermission::kBackground))
+ // Not a background app if we don't have the background permission or
+ // the push messaging permission
+ if (!extension.HasAPIPermission(APIPermission::kBackground) &&
+ !extension.HasAPIPermission(APIPermission::kPushMessaging) )
return false;
// Extensions and packaged apps with background permission are always treated
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698